@@ -1,10 +1,11 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from abc import ABCMeta, abstractmethod
 from pathlib import Path
 
+from grizzly.common.utils import DEFAULT_TIME_LIMIT
+
 __all__ = ("Adapter", "AdapterError")
 __author__ = "Tyson Smith"
 __credits__ = ["Tyson Smith"]
@@ -42,7 +43,7 @@ class Adapter(metaclass=ABCMeta):
     # Maximum execution time per test (used as minimum timeout). The iteration is
     # expected to be complete. If the test is still open the harness will attempt to
     # close it.
-    TIME_LIMIT = 30
+    TIME_LIMIT = DEFAULT_TIME_LIMIT
 
     __slots__ = ("_harness", "fuzz", "monitor", "name", "remaining")
 
@@ -51,7 +52,7 @@ class Adapter(metaclass=ABCMeta):
         if not name:
             raise AdapterError("name must not be empty")
         self._harness = None
-        self.fuzz = dict()
+        self.fuzz = {}
         self.monitor = None
         self.name = name
         self.remaining = None
@@ -73,16 +74,16 @@ class Adapter(metaclass=ABCMeta):
         *** DO NOT OVERLOAD! ***
 
         Args:
-            file_path (str): Path to file to use as a harness. If None the default
-                             harness is used.
+            file_path (str): Path to (html) file to use as a harness.
+                             If None the default harness is used.
 
         Returns:
             None
         """
-        if file_path is None:
-            file_path = self.HARNESS_FILE
-        with open(file_path, "rb") as in_fp:
-            self._harness = in_fp.read()
+        path = Path(self.HARNESS_FILE if file_path is None else file_path)
+        assert path.is_file(), f"missing harness file '{path.resolve()}'"
+        self._harness = path.read_bytes()
+        assert self._harness, f"empty harness file '{path.resolve()}'"
 
     def get_harness(self):
         """Get the harness. Used internally by Grizzly.
@@ -92,7 +93,7 @@ class Adapter(metaclass=ABCMeta):
             None
 
         Returns:
-            TestFile: The active harness.
+            bytes: The active harness.
         """
         return self._harness
 
