@@ -1,16 +1,16 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from argparse import ArgumentParser, HelpFormatter
 from logging import CRITICAL, DEBUG, ERROR, INFO, WARNING
+from os import getenv
 from os.path import exists, isfile
 from pathlib import Path
 from platform import system
 
 from .common.plugins import scan as scan_plugins
 from .common.plugins import scan_target_assets
-from .common.utils import TIMEOUT_DELAY
+from .common.utils import DEFAULT_TIME_LIMIT, TIMEOUT_DELAY
 
 
 # ref: https://stackoverflow.com/questions/12268602/sort-argparse-help-alphabetically
@@ -44,12 +44,10 @@ class CommonArgs:
             "INFO": INFO,
             "DEBUG": DEBUG,
         }
-        self._sanity_skip = set()
 
-        if not hasattr(self, "parser"):
-            self.parser = ArgumentParser(
-                formatter_class=SortingHelpFormatter, conflict_handler="resolve"
-            )
+        self.parser = ArgumentParser(
+            formatter_class=SortingHelpFormatter, conflict_handler="resolve"
+        )
 
         targets = scan_plugins("grizzly_targets")
         if not targets:
@@ -65,21 +63,19 @@ class CommonArgs:
 
         # build 'asset' help string
         assets = scan_target_assets()
-        asset_msg = list()
+        asset_msg = []
         for target in sorted(assets):
             if assets[target]:
-                asset_msg.append(
-                    "%s: %s. " % (target, ", ".join(sorted(assets[target])))
-                )
+                asset_msg.append(f"{target}: {', '.join(sorted(assets[target]))}.")
 
         self.launcher_grp = self.parser.add_argument_group("Launcher Arguments")
         self.launcher_grp.add_argument(
             "--asset",
             action="append",
-            default=list(),
+            default=[],
             metavar=("ASSET", "PATH"),
             nargs=2,
-            help="Specify target specific asset files. %s" % ("".join(asset_msg),),
+            help=f"Specify target specific asset files. {''.join(asset_msg)}",
         )
         self.launcher_grp.add_argument(
             "-e",
@@ -87,6 +83,11 @@ class CommonArgs:
             help="DEPRECATED. Install an extension. Specify the path to the xpi or the"
             " directory containing the unpacked extension.",
         )
+        self.launcher_grp.add_argument(
+            "--display-launch-failures",
+            action="store_true",
+            help="Output launch failure logs to console. (default: %(default)s)",
+        )
         headless_choices = ["default"]
         if system().startswith("Linux"):
             headless_choices.append("xvfb")
@@ -94,7 +95,7 @@ class CommonArgs:
             "--headless",
             choices=headless_choices,
             const="default",
-            default=None,
+            default="default" if self.is_headless() else None,
             nargs="?",
             help="Headless mode. 'default' uses browser's built-in headless mode.",
         )
@@ -125,6 +126,11 @@ class CommonArgs:
             default=0,
             help="Browser process memory limit in MBs (default: 'no limit')",
         )
+        self.launcher_grp.add_argument(
+            "--no-harness",
+            action="store_true",
+            help="Don't use the harness for redirection. Implies '--relaunch=1'.",
+        )
         self.launcher_grp.add_argument(
             "--platform",
             default="ffpuppet",
@@ -145,21 +151,25 @@ class CommonArgs:
             "--time-limit",
             type=int,
             default=None,
-            help="This is the maximum amount of time that a test is expected to take."
-            " After the time has elapsed the harness will attempt to close the test."
-            " By default `Adapter.TIME_LIMIT` is used."
+            help="Maximum expected execution time of a test case."
+            " If time-limit is reached before the test case has closed"
+            " the harness will attempt to close the test. If this fails for any reason"
+            " '--timeout' is the fallback."
             " Browser build types and debuggers can affect the amount of time"
-            " required to run a test case.",
+            " required for test case execution to complete."
+            " (default: fuzzing - set by 'Adapter.TIME_LIMIT'; reduce/replay - "
+            f"duration from loaded test case or minimum {DEFAULT_TIME_LIMIT}s)",
         )
         self.launcher_grp.add_argument(
             "-t",
             "--timeout",
             type=int,
             default=None,
-            help="Iteration timeout in seconds. By default this is `test-duration`+%ds."
-            " If the timeout is reached the target is assumed to be in a bad state"
-            " and will be closed. Typically this should be a few seconds greater"
-            " than the value used for `test-duration`." % (TIMEOUT_DELAY,),
+            help="Test case execution (iteration) timeout."
+            " If timeout is reached before the test case has closed"
+            " the target will be closed."
+            " Typically this should be '--time-limit' + a few seconds."
+            f" (default: '--test-limit' + {TIMEOUT_DELAY}s)",
         )
         if system().startswith("Linux"):
             self.launcher_grp.add_argument(
@@ -177,10 +187,8 @@ class CommonArgs:
             nargs="*",
             choices=self.IGNORABLE,
             default=self.DEFAULT_IGNORE,
-            metavar="IGNORABLE",
-            help="Space-separated list of ignorable types. Pass zero args to disable."
-            " Available: %s (default: %s)"
-            % (" ".join(self.IGNORABLE), " ".join(self.DEFAULT_IGNORE)),
+            help="Result types to ignore. Pass zero args to disable. NOTE: 'memory'"
+            " only applies to OOMs detected by Grizzly. (default: %(default)s)",
         )
         self.reporter_grp.add_argument(
             "-l",
@@ -217,14 +225,24 @@ class CommonArgs:
             " https://github.com/MozillaSecurity/grizzly/wiki"
         )
 
+    @staticmethod
+    def is_headless():
+        if (
+            system().startswith("Linux")
+            and not getenv("DISPLAY")
+            and not getenv("WAYLAND_DISPLAY")
+        ):
+            return True
+        return False
+
     def parse_args(self, argv=None):
         args = self.parser.parse_args(argv)
         self.sanity_check(args)
         return args
 
     def sanity_check(self, args):
-        if "binary" not in self._sanity_skip and not isfile(args.binary):
-            self.parser.error("file not found: %r" % (args.binary,))
+        if not isfile(args.binary):
+            self.parser.error(f"file not found: {args.binary!r}")
 
         if args.launch_attempts < 1:
             self.parser.error("--launch-attempts must be >= 1")
@@ -243,6 +261,12 @@ class CommonArgs:
             self.parser.error("--memory must be >= 0")
         args.memory *= 1_048_576
 
+        if args.no_harness:
+            if args.time_limit is not None:
+                self.parser.error("--time-limit cannot be used with --no-harness")
+            # --no-harness implies --relaunch 1
+            args.relaunch = 1
+
         if args.relaunch < 1:
             self.parser.error("--relaunch must be >= 1")
 
@@ -251,7 +275,7 @@ class CommonArgs:
             settings = "/proc/sys/kernel/perf_event_paranoid"
             value = int(Path(settings).read_text())
             if value > 1:
-                self.parser.error("rr needs %s <= 1, but it is %d" % (settings, value))
+                self.parser.error(f"rr needs {settings} <= 1, but it is {value}")
 
         # TODO: remove deprecated 'extension' from args
         if args.extension:  # pragma: no cover
@@ -267,11 +291,11 @@ class CommonArgs:
             for asset, path in args.asset:
                 if not supported_assets or asset not in supported_assets:
                     self.parser.error(
-                        "Asset %r not supported by target %r" % (asset, args.platform)
+                        f"Asset {asset!r} not supported by target {args.platform!r}"
                     )
                 if not exists(path):
                     self.parser.error(
-                        "Failed to add asset %r cannot find %r" % (asset, path)
+                        f"Failed to add asset {asset!r} cannot find {path!r}"
                     )
 
         if args.time_limit is not None and args.time_limit < 1:
@@ -280,9 +304,11 @@ class CommonArgs:
         if args.timeout is not None and args.timeout < 1:
             self.parser.error("--timeout must be >= 1")
 
-        if "tool" not in self._sanity_skip:
-            if args.tool is not None and not args.fuzzmanager:
-                self.parser.error("--tool can only be given with --fuzzmanager")
+        if args.time_limit and args.timeout and args.timeout < args.time_limit:
+            self.parser.error("--timeout must be >= --time-limit")
+
+        if args.tool is not None and not args.fuzzmanager:
+            self.parser.error("--tool requires --fuzzmanager")
 
         if args.xvfb:  # pragma: no cover
             args.headless = "xvfb"
@@ -296,7 +322,6 @@ class GrizzlyArgs(CommonArgs):
         if not adapters:
             self.parser.error("No Adapters are installed")
 
-        self._sanity_skip.add("tool")
         self.parser.add_argument(
             "adapter", choices=sorted(adapters), help="Adapter to use."
         )
@@ -363,12 +388,6 @@ class GrizzlyArgs(CommonArgs):
             " The first time a result is seen it will always be submitted."
             " (default: %(default)s) - Use 0 for 'no limit'",
         )
-        self.reporter_grp.add_argument(
-            "--s3-fuzzmanager",
-            action="store_true",
-            help="Report large attachments (if any) to S3 and then the crash &"
-            " S3 link to FuzzManager.",
-        )
 
     def sanity_check(self, args):
         super().sanity_check(args)
@@ -376,13 +395,8 @@ class GrizzlyArgs(CommonArgs):
         if args.collect < 1:
             self.parser.error("--collect must be greater than 0")
 
-        if args.fuzzmanager and args.s3_fuzzmanager:
-            self.parser.error(
-                "--fuzzmanager and --s3-fuzzmanager are mutually exclusive"
-            )
-
         if args.input and not args.input.exists():
-            self.parser.error("'%s' does not exist" % (args.input,))
+            self.parser.error(f"'{args.input}' does not exist")
 
         if args.limit < 0:
             self.parser.error("--limit must be >= 0")
@@ -393,7 +407,7 @@ class GrizzlyArgs(CommonArgs):
         if args.runtime < 0:
             self.parser.error("--runtime must be >= 0")
 
-        if args.tool is not None and not (args.fuzzmanager or args.s3_fuzzmanager):
-            self.parser.error(
-                "--tool can only be given with --fuzzmanager/--s3-fuzzmanager"
-            )
+        if args.smoke_test:
+            if args.limit == 0:
+                # set iteration limit for smoke-test
+                args.limit = 10
