@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -31,11 +30,9 @@ class Bucket:
         self._bucket_id = bucket_id
         self._sig_filename = None
         self._coll = Collector()
-        self._url = "%s://%s:%d/crashmanager/rest/buckets/%d/" % (
-            self._coll.serverProtocol,
-            self._coll.serverHost,
-            self._coll.serverPort,
-            bucket_id,
+        self._url = (
+            f"{self._coll.serverProtocol}://{self._coll.serverHost}:"
+            f"{self._coll.serverPort}/crashmanager/rest/buckets/{bucket_id}/"
         )
         self._data = None
 
@@ -54,8 +51,8 @@ class Bucket:
             self._data = self._coll.get(self._url).json()
         if name not in self._data:
             raise AttributeError(
-                "'%s' object has no attribute '%s' (has: %s)"
-                % (type(self).__name__, name, list(self._data))
+                f"'{type(self).__name__,}' object has no attribute '{name}'"
+                f" (has: {list(self._data)})"
             )
         return self._data[name]
 
@@ -75,7 +72,7 @@ class Bucket:
             None
         """
         if self._sig_filename is not None:
-            rmtree(str(self._sig_filename.parent))
+            rmtree(self._sig_filename.parent)
 
     def iter_crashes(self, quality_filter=None):
         """Fetch all crash IDs for this FuzzManager bucket.
@@ -101,11 +98,9 @@ class Bucket:
             """
             LOG.debug("first request to /%s/", endpoint)
 
-            url = "%s://%s:%d/crashmanager/rest/%s/" % (
-                self._coll.serverProtocol,
-                self._coll.serverHost,
-                self._coll.serverPort,
-                endpoint,
+            url = (
+                f"{self._coll.serverProtocol}://{self._coll.serverHost}:"
+                f"{self._coll.serverPort}/crashmanager/rest/{endpoint}/"
             )
 
             response = self._coll.get(url, params=params).json()
@@ -163,12 +158,10 @@ class Bucket:
             return self._sig_filename
 
         tmpd = Path(
-            mkdtemp(
-                prefix="bucket-%d-" % (self._bucket_id,), dir=grz_tmp("fuzzmanager")
-            )
+            mkdtemp(prefix=f"bucket-{self._bucket_id}-", dir=grz_tmp("fuzzmanager"))
         )
         try:
-            sig_basename = "%d.signature" % (self._bucket_id,)
+            sig_basename = f"{self._bucket_id}.signature"
             sig_filename = tmpd / sig_basename
             sig_filename.write_text(self.signature)
             sigmeta_filename = sig_filename.with_suffix(".metadata")
@@ -183,7 +176,7 @@ class Bucket:
                 )
             )
         except:  # noqa pragma: no cover pylint: disable=bare-except
-            rmtree(str(tmpd))
+            rmtree(tmpd)
             raise
 
         self._sig_filename = sig_filename
@@ -209,11 +202,9 @@ class CrashEntry:
         assert isinstance(crash_id, int)
         self._crash_id = crash_id
         self._coll = Collector()
-        self._url = "%s://%s:%d/crashmanager/rest/crashes/%d/" % (
-            self._coll.serverProtocol,
-            self._coll.serverHost,
-            self._coll.serverPort,
-            crash_id,
+        self._url = (
+            f"{self._coll.serverProtocol}://{self._coll.serverHost}:"
+            f"{self._coll.serverPort}/crashmanager/rest/crashes/{crash_id}/"
         )
         self._data = None
         self._tc_filename = None
@@ -237,8 +228,8 @@ class CrashEntry:
             ).json()
         if name not in self._data:
             raise AttributeError(
-                "'%s' object has no attribute '%s' (has: %s)"
-                % (type(self).__name__, name, list(self._data))
+                f"'{type(self).__name__}' object has no attribute '{name}' "
+                f"(has: {list(self._data)})"
             )
         return self._data[name]
 
@@ -281,12 +272,12 @@ class CrashEntry:
 
         if "content-disposition" not in response.headers:
             raise RuntimeError(
-                "Server sent malformed response: %r" % (response,)
+                f"Server sent malformed response: {response!r}"
             )  # pragma: no cover
 
         handle, filename = mkstemp(
             dir=grz_tmp("fuzzmanager"),
-            prefix="crash-%d-" % (self.crash_id,),
+            prefix=f"crash-{self.crash_id}-",
             suffix=Path(self.testcase).suffix,
         )
         try:
