@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -16,6 +15,8 @@ __author__ = "Tyson Smith"
 __credits__ = ["Tyson Smith"]
 
 LOG = getLogger(__name__)
+# display warning if launch duration exceeds set value
+SLOW_LAUNCH_THRESHOLD = 20
 
 
 class _IdleChecker:
@@ -124,31 +125,40 @@ class Runner:
         self._server.clear_backlog()
         self._tests_run = 0
         self.startup_failure = False
+        launch_duration = 0
         LOG.debug("launching target (timeout %ds)", self._target.launch_timeout)
         for retries in reversed(range(max_retries)):
             try:
+                launch_start = time()
                 self._target.launch(location)
-            except TargetLaunchError as exc:
-                # This is likely due to a bad build or environment configuration.
-                if retries:
-                    LOG.warning("Failure detected during launch (retries %d)", retries)
+                launch_duration = time() - launch_start
+            except (TargetLaunchError, TargetLaunchTimeout) as exc:
+                if not retries:
+                    self.startup_failure = True
+                    LOG.error(
+                        "Launch failed, please verify browser build works as expected"
+                    )
+                    raise
+                if isinstance(exc, TargetLaunchError):
+                    # This is likely due to a bad build or environment configuration.
+                    LOG.warning("Failure during launch (retries %d)", retries)
                     exc.report.cleanup()
-                    sleep(retry_delay)
-                    continue
-                self.startup_failure = True
-                raise
-            except TargetLaunchTimeout:
-                # A TargetLaunchTimeout likely has nothing to do with Grizzly but is
-                # seen frequently on machines under a high load. After multiple
-                # consecutive timeouts something is likely wrong so raise.
-                if retries:
-                    LOG.warning("Timeout detected during launch (retries %d)", retries)
-                    sleep(retry_delay)
-                    continue
-                self.startup_failure = True
-                raise
+                else:
+                    # A TargetLaunchTimeout likely has nothing to do with Grizzly but is
+                    # seen frequently on machines under a high load. After multiple
+                    # consecutive timeouts something is likely wrong so raise.
+                    LOG.warning("Timeout during launch (retries %d)", retries)
+                sleep(retry_delay)
+                continue
             break
 
+        if launch_duration > SLOW_LAUNCH_THRESHOLD:
+            LOG.warning(
+                "Slow launch detected (%0.1fs > %ds)",
+                launch_duration,
+                SLOW_LAUNCH_THRESHOLD,
+            )
+
     @staticmethod
     def location(
         srv_path, srv_port, close_after=None, post_launch_delay=None, time_limit=None
@@ -165,18 +175,18 @@ class Runner:
         Returns:
             str: A valid URL.
         """
-        location = "http://127.0.0.1:%d/%s" % (srv_port, srv_path.lstrip("/"))
+        location = f"http://127.0.0.1:{srv_port}/{srv_path.lstrip('/')}"
         # set harness related arguments
         args = []
         if close_after is not None:
             assert close_after >= 0
-            args.append("close_after=%d" % (close_after,))
+            args.append(f"close_after={close_after}")
         if time_limit:
             assert time_limit > 0
-            args.append("time_limit=%d" % (time_limit * 1000,))
+            args.append(f"time_limit={time_limit * 1000}")
         if post_launch_delay is not None:
             assert post_launch_delay >= 0
-            args.append("post_launch_delay=%d" % (post_launch_delay,))
+            args.append(f"post_launch_delay={post_launch_delay}")
         if args:
             return "?".join((location, "&".join(args)))
         return location
@@ -282,7 +292,8 @@ class Runner:
             )
         if result.timeout:
             LOG.debug("timeout detected")
-            if self._target.handle_hang(ignore_idle=True) or "timeout" in ignore:
+            result.idle = self._target.handle_hang(ignore_idle=True)
+            if result.idle or "timeout" in ignore:
                 result.status = Result.IGNORED
             server_map.dynamic.pop("grz_empty", None)
         if result.attempted:
@@ -352,15 +363,23 @@ class RunResult:
         served (tuple(str)): Files that were served.
         status (int): Result status of test.
         timeout (bool): A timeout occurred waiting for test to complete.
+        idle (bool): Target was idle (only applies to timeout).
     """
 
-    __slots__ = ("attempted", "duration", "served", "status", "timeout")
+    __slots__ = ("attempted", "duration", "idle", "served", "status", "timeout")
 
     def __init__(
-        self, served, duration, attempted=False, status=Result.NONE, timeout=False
+        self,
+        served,
+        duration,
+        attempted=False,
+        status=Result.NONE,
+        timeout=False,
+        idle=False,
     ):
         self.attempted = attempted
         self.duration = duration
+        self.idle = idle
         self.served = served
         self.status = status
         self.timeout = timeout
