@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -16,15 +15,22 @@ try:
 except ImportError:  # pragma: no cover
     # os.getloadavg() is not available on all platforms
     getloadavg = None
-from os import SEEK_CUR, getenv, scandir
-from os.path import isdir
+from os import SEEK_CUR, getenv
+from pathlib import Path
 from re import match
 from re import sub as re_sub
 from time import gmtime, localtime, strftime
 
 from psutil import cpu_count, cpu_percent, disk_usage, virtual_memory
 
-from .status import ReductionStatus, ReductionStep, Status
+from .status import (
+    REPORT_RATE,
+    STATUS_DB_FUZZ,
+    STATUS_DB_REDUCE,
+    ReadOnlyStatus,
+    ReductionStatus,
+    ReductionStep,
+)
 
 __all__ = ("StatusReporter",)
 __author__ = "Tyson Smith"
@@ -55,18 +61,17 @@ class StatusReporter:
         """Read Grizzly status reports and create a StatusReporter object.
 
         Args:
-            path (str): Path to scan for status data files.
-            tb_path (str): Directory to scan for files containing Python tracebacks.
+            db_file (str): Status data file to load.
+            tb_path (Path): Directory to scan for files containing Python tracebacks.
             time_limit (int): Only include entries with a timestamp that is within the
                               given number of seconds.
 
         Returns:
             StatusReporter: Contains available status reports and traceback reports.
         """
-        tracebacks = None if tb_path is None else cls._tracebacks(tb_path)
         return cls(
-            list(Status.loadall(db_file=db_file, time_limit=time_limit)),
-            tracebacks=tracebacks,
+            list(ReadOnlyStatus.load_all(db_file, time_limit=time_limit)),
+            tracebacks=None if tb_path is None else cls._tracebacks(tb_path),
         )
 
     @staticmethod
@@ -95,12 +100,10 @@ class StatusReporter:
         """
         label_lengths = tuple(len(x[0]) for x in entries if x[1])
         max_len = max(label_lengths) if label_lengths else 0
-        out = list()
+        out = []
         for label, body in entries:
             if body:
-                out.append(
-                    "%s%s : %s" % ((" " * max(max_len - len(label), 0), label, body))
-                )
+                out.append(f"{label}".rjust(max_len) + f" : {body}")
             else:
                 out.append(label)
         return "\n".join(out)
@@ -116,21 +119,21 @@ class StatusReporter:
         """
         blockers = set()
         counts = defaultdict(int)
-        descs = dict()
+        descs = {}
         # calculate totals
         for report in self.reports:
-            for result in report.results.all():
+            for result in report.results:
                 descs[result.rid] = result.desc
                 counts[result.rid] += result.count
-            blockers.update(x.rid for x in report.blockers())
+            blockers.update(x.rid for x in report.results.blockers(report.iteration))
         # generate output
-        entries = list()
+        entries = []
         for rid, count in sorted(counts.items(), key=lambda x: x[1], reverse=True):
             desc = descs[rid]
             # trim long descriptions
             if len(descs[rid]) > max_len:
-                desc = "%s..." % (desc[: max_len - 3],)
-            label = "%s%d" % ("*" if rid in blockers else "", count)
+                desc = f"{desc[: max_len - 3]}..."
+            label = f"*{count}" if rid in blockers else str(count)
             entries.append((label, desc))
         if not entries:
             entries.append(("No results available", None))
@@ -139,16 +142,6 @@ class StatusReporter:
         entries.append(("", None))
         return self.format_entries(entries)
 
-    @staticmethod
-    def _scan(path, fname_pattern):
-        for entry in scandir(path):
-            if match(fname_pattern, entry.name) is None:
-                continue
-            if not entry.is_file():
-                continue
-            if entry.stat().st_size:
-                yield entry.path
-
     def specific(self, iters_per_result=100):
         """Merged and generate formatted output from status reports.
 
@@ -161,40 +154,38 @@ class StatusReporter:
         if not self.reports:
             return "No status reports available"
         self.reports.sort(key=lambda x: x.start_time)
-        entries = list()
+        entries = []
         for report in self.reports:
-            label = "PID %d started at %s" % (
-                report.pid,
-                strftime("%Y/%m/%d %X", localtime(report.start_time)),
+            label = (
+                f"PID {report.pid} started at "
+                f"{strftime('%Y/%m/%d %X', localtime(report.start_time))}"
             )
             entries.append((label, None))
             # iterations
             entries.append(
-                ("Iterations", "%d @ %0.2f" % (report.iteration, round(report.rate, 2)))
+                ("Iterations", f"{report.iteration} @ {round(report.rate, 2):0.2f}")
             )
             # ignored
             if report.ignored:
-                ignore_pct = report.ignored / float(report.iteration) * 100
+                ignore_pct = report.ignored / report.iteration * 100
                 entries.append(
-                    (
-                        "Ignored",
-                        "%d @ %0.1f%%" % (report.ignored, round(ignore_pct, 1)),
-                    )
+                    ("Ignored", f"{report.ignored} @ {round(ignore_pct, 1)}%")
                 )
             # results
             if report.results.total:
                 # avoid divide by zero if results are found before first update
                 iters = report.iteration if report.iteration else report.results.total
-                result_pct = report.results.total / float(iters) * 100
-                if any(report.blockers(iters_per_result=iters_per_result)):
-                    blk_str = " (Blockers detected)"
+                result_pct = report.results.total / iters * 100
+                if any(
+                    report.results.blockers(iters, iters_per_result=iters_per_result)
+                ):
+                    blkd = " (Blockers detected)"
                 else:
-                    blk_str = ""
+                    blkd = ""
                 entries.append(
                     (
                         "Results",
-                        "%d @ %0.1f%% %s"
-                        % (report.results.total, round(result_pct, 1), blk_str),
+                        f"{report.results.total} @ {round(result_pct, 1):0.1f}%{blkd}",
                     )
                 )
             else:
@@ -207,19 +198,19 @@ class StatusReporter:
                 for entry in sorted(
                     report.profile_entries(), key=lambda x: x.total, reverse=True
                 ):
-                    avg = entry.total / float(entry.count)
-                    body = list()
-                    body.append("%dx " % (entry.count,))
+                    avg = entry.total / entry.count
+                    body = []
+                    body.append(f"{entry.count}x ")
                     if entry.total > 300:
                         body.append(str(timedelta(seconds=int(entry.total))))
                     else:
-                        body.append("%0.3fs" % (round(entry.total, 3),))
+                        body.append(f"{round(entry.total, 3):0.3f}s")
                     body.append(
-                        " %0.2f%%" % (round(entry.total / report.runtime * 100, 2),)
+                        f" {round(entry.total / report.runtime * 100, 2):0.2f}%"
                     )
-                    body.append(" (%0.3f avg," % (round(avg, 3),))
-                    body.append(" %0.3f max," % (round(entry.max, 3),))
-                    body.append(" %0.3f min)" % (round(entry.min, 3),))
+                    body.append(f" ({round(avg, 3):0.3f} avg,")
+                    body.append(f" {round(entry.max, 3):0.3f} max,")
+                    body.append(f" {round(entry.min, 3):0.3f} min)")
                     entries.append((entry.name, "".join(body)))
             entries.append(("", None))
         return self.format_entries(entries)
@@ -238,7 +229,7 @@ class StatusReporter:
         Returns:
             str: A summary of merged reports.
         """
-        entries = list()
+        entries = []
         # Job specific status
         if self.reports:
             # calculate totals
@@ -251,41 +242,46 @@ class StatusReporter:
             total_iters = sum(iterations)
 
             # Iterations
-            disp = list()
+            disp = []
             disp.append(str(total_iters))
             if count > 1:
-                disp.append(" (%d, %d)" % (max(iterations), min(iterations)))
+                disp.append(f" ({max(iterations)}, {min(iterations)})")
             entries.append(("Iterations", "".join(disp)))
 
             # Rate
-            disp = list()
-            disp.append("%d @ %0.2f" % (count, round(sum(rates), 2)))
+            disp = []
+            disp.append(f"{count} @ {round(sum(rates), 2):0.2f}")
             if count > 1:
                 disp.append(
-                    " (%0.2f, %0.2f)" % (round(max(rates), 2), round(min(rates), 2))
+                    f" ({round(max(rates), 2):0.2f}, {round(min(rates), 2):0.2f})"
                 )
             entries.append(("Rate", "".join(disp)))
 
             # Results
             if total_iters:
                 total_results = sum(results)
-                result_pct = total_results / float(total_iters) * 100
-                disp = list()
-                disp.append("%d" % (total_results,))
+                result_pct = total_results / total_iters * 100
+                disp = []
+                disp.append(str(total_results))
                 if total_results:
-                    disp.append(" @ %0.1f%%" % (round(result_pct, 1),))
+                    disp.append(f" @ {round(result_pct, 1):0.1f}%")
                 if any(
-                    any(x.blockers(iters_per_result=iters_per_result))
-                    for x in self.reports
+                    any(
+                        report.results.blockers(
+                            report.iteration, iters_per_result=iters_per_result
+                        )
+                    )
+                    for report in self.reports
+                    if report.iteration > 0
                 ):
                     disp.append(" (Blockers)")
                 entries.append(("Results", "".join(disp)))
 
             # Ignored
             if total_ignored:
-                ignore_pct = total_ignored / float(total_iters) * 100
+                ignore_pct = total_ignored / total_iters * 100
                 entries.append(
-                    ("Ignored", "%d @ %0.1f%%" % (total_ignored, round(ignore_pct, 1)))
+                    ("Ignored", f"{total_ignored} @ {round(ignore_pct, 1):0.1f}%")
                 )
 
             # Runtime
@@ -294,14 +290,14 @@ class StatusReporter:
                 entries.append(("Runtime", str(timedelta(seconds=int(total_runtime)))))
 
             # Log size
-            log_usage = sum(log_sizes) / 1_048_576.0
+            log_usage = sum(log_sizes) / 1_048_576
             if log_usage > self.DISPLAY_LIMIT_LOG:
-                disp = list()
-                disp.append("%0.1fMB" % (log_usage,))
+                disp = []
+                disp.append(f"{log_usage:0.1f}MB")
                 if count > 1:
                     disp.append(
-                        " (%0.2fMB, %0.2fMB)"
-                        % (max(log_sizes) / 1_048_576.0, min(log_sizes) / 1_048_576.0)
+                        f" ({max(log_sizes) / 1_048_576:0.2f}MB, "
+                        f"{min(log_sizes) / 1_048_576:0.2f}MB)"
                     )
                 entries.append(("Logs", "".join(disp)))
         else:
@@ -334,8 +330,8 @@ class StatusReporter:
         Returns:
             str: merged tracebacks.
         """
-        txt = list()
-        txt.append("\n\nWARNING Tracebacks (%d) detected!" % (len(tracebacks),))
+        txt = []
+        txt.append(f"\n\nWARNING Tracebacks ({len(tracebacks)}) detected!")
         tb_size = len(txt[-1])
         for tbr in tracebacks:
             tb_size += len(tbr) + 1
@@ -354,43 +350,39 @@ class StatusReporter:
         Returns:
             list(tuple): System information in tuples (label, display data).
         """
-        entries = list()
+        entries = []
 
         # CPU and load
-        disp = list()
+        disp = []
         disp.append(
-            "%d (%d) @ %d%%"
-            % (
-                cpu_count(logical=True),
-                cpu_count(logical=False),
-                round(cpu_percent(interval=StatusReporter.CPU_POLL_INTERVAL)),
-            )
+            f"{cpu_count(logical=True)} ({cpu_count(logical=False)}) @ "
+            f"{round(cpu_percent(interval=StatusReporter.CPU_POLL_INTERVAL))}%"
         )
         if getloadavg is not None:
             disp.append(" (")
             # round the results of getloadavg(), precision varies across platforms
-            disp.append(", ".join("%0.1f" % (round(x, 1),) for x in getloadavg()))
+            disp.append(", ".join(f"{round(x, 1):0.1f}" for x in getloadavg()))
             disp.append(")")
         entries.append(("CPU & Load", "".join(disp)))
 
         # memory usage
-        disp = list()
+        disp = []
         mem_usage = virtual_memory()
         if mem_usage.available < 1_073_741_824:  # < 1GB
-            disp.append("%dMB" % (mem_usage.available / 1_048_576,))
+            disp.append(f"{int(mem_usage.available / 1_048_576)}MB")
         else:
-            disp.append("%0.1fGB" % (mem_usage.available / 1_073_741_824.0,))
-        disp.append(" of %0.1fGB free" % (mem_usage.total / 1_073_741_824.0,))
+            disp.append(f"{mem_usage.available / 1_073_741_824:0.1f}GB")
+        disp.append(f" of {mem_usage.total / 1_073_741_824:0.1f}GB free")
         entries.append(("Memory", "".join(disp)))
 
         # disk usage
-        disp = list()
+        disp = []
         usage = disk_usage("/")
         if usage.free < 1_073_741_824:  # < 1GB
-            disp.append("%dMB" % (usage.free / 1_048_576,))
+            disp.append(f"{int(usage.free / 1_048_576)}MB")
         else:
-            disp.append("%0.1fGB" % (usage.free / 1_073_741_824.0,))
-        disp.append(" of %0.1fGB free" % (usage.total / 1_073_741_824.0,))
+            disp.append(f"{usage.free / 1_073_741_824:0.1f}GB")
+        disp.append(f" of {usage.total / 1_073_741_824:0.1f}GB free")
         entries.append(("Disk", "".join(disp)))
 
         return entries
@@ -400,22 +392,21 @@ class StatusReporter:
         """Search screen logs for tracebacks.
 
         Args:
-            path (str): Directory containing log files.
-            ignore_kbi (bool): Do not include KeyboardInterupts in results
+            path (Path): Directory containing log files.
+            ignore_kbi (bool): Do not include KeyboardInterrupts in results
             max_preceding (int): Maximum number of lines preceding traceback to
                                   include.
 
         Returns:
             list: A list of TracebackReports.
         """
-        tracebacks = list()
-        for screen_log in StatusReporter._scan(path, r"screenlog\.\d+"):
-            tbr = TracebackReport.from_file(screen_log, max_preceding=max_preceding)
-            if tbr is None:
-                continue
-            if ignore_kbi and tbr.is_kbi:
-                continue
-            tracebacks.append(tbr)
+        tracebacks = []
+        for screen_log in (x for x in path.glob("screenlog.*") if x.is_file()):
+            tbr = TracebackReport.from_file(
+                screen_log, max_preceding=max_preceding, ignore_kbi=ignore_kbi
+            )
+            if tbr:
+                tracebacks.append(tbr)
         return tracebacks
 
 
@@ -425,31 +416,34 @@ class TracebackReport:
     """
 
     MAX_LINES = 16  # should be no less than 6
-    READ_LIMIT = 0x10000  # 64KB
+    READ_LIMIT = 0x20000  # 128KB
 
-    def __init__(self, file_name, lines, is_kbi=False, prev_lines=None):
+    def __init__(self, log_file, lines, is_kbi=False, prev_lines=None):
         assert isinstance(lines, list)
-        self.file_name = file_name
-        self.lines = lines
-        self.prev_lines = list() if prev_lines is None else prev_lines
+        assert isinstance(log_file, Path)
+        assert isinstance(prev_lines, list) or prev_lines is None
         self.is_kbi = is_kbi
+        self.lines = lines
+        self.log_file = log_file
+        self.prev_lines = prev_lines or []
 
     @classmethod
-    def from_file(cls, input_log, max_preceding=5):
+    def from_file(cls, log_file, max_preceding=5, ignore_kbi=False):
         """Create TracebackReport from a text file containing a Python traceback.
         Only the first traceback in the file will be parsed.
 
         Args:
-            input_log (str): File to parse.
+            log_file (Path): File to parse.
             max_preceding (int): Number of lines to collect leading up to the traceback.
+            ignore_kbi (bool): Skip/ignore KeyboardInterrupt.
 
         Returns:
-            TracebackReport: Contains data from input_log.
+            TracebackReport: Contains data from log_file.
         """
         token = b"Traceback (most recent call last):"
         assert len(token) < cls.READ_LIMIT
         try:
-            with open(input_log, "rb") as in_fp:
+            with log_file.open("rb") as in_fp:
                 for chunk in iter(partial(in_fp.read, cls.READ_LIMIT), b""):
                     idx = chunk.find(token)
                     if idx > -1:
@@ -487,6 +481,9 @@ class TracebackReport:
                     break
                 if match(r"^\w+(\.\w+)*\:\s|^\w+(Interrupt|Error)$", log_line):
                     is_kbi = log_line.startswith("KeyboardInterrupt")
+                    if is_kbi and ignore_kbi:
+                        # ignore this exception since it is a KeyboardInterrupt
+                        return None
                     # stop after error message
                     tb_end = min(line_num + 1, line_count)
                     break
@@ -507,13 +504,15 @@ class TracebackReport:
             lines += data[tb_end - (cls.MAX_LINES - 3) : tb_end]
         else:
             lines = data[tb_start:tb_end]
-        return cls(input_log, lines, is_kbi=is_kbi, prev_lines=prev_lines)
+        return cls(log_file, lines, is_kbi=is_kbi, prev_lines=prev_lines)
 
     def __len__(self):
         return len(str(self))
 
     def __str__(self):
-        return "\n".join(["Log: %r" % self.file_name] + self.prev_lines + self.lines)
+        return "\n".join(
+            [f"Log: '{self.log_file.name}'"] + self.prev_lines + self.lines
+        )
 
 
 class _TableFormatter:
@@ -577,7 +576,7 @@ def _format_seconds(duration):
     # format H:M:S, and then remove all leading zeros with regex
     minutes, seconds = divmod(int(duration), 60)
     hours, minutes = divmod(minutes, 60)
-    result = re_sub("^[0:]*", "", "%d:%02d:%02d" % (hours, minutes, seconds))
+    result = re_sub("^[0:]*", "", f"{hours}:{minutes:0>2d}:{seconds:0>2d}")
     # if the result is all zeroes, ensure one zero is output
     if not result:
         result = "0"
@@ -595,7 +594,7 @@ def _format_duration(duration, total=0):
         else:
             percent = int(100 * duration / total)
         result = _format_seconds(duration)
-        result += " (%3d%%)" % (percent,)
+        result += f" ({percent:>3d}%)"
     return result
 
 
@@ -606,7 +605,7 @@ def _format_number(number, total=0):
             percent = 0
         else:
             percent = int(100 * number / total)
-        result = "{:n} ({:3d}%)".format(number, percent)
+        result = f"{number:n} ({percent:3d}%)"
     return result
 
 
@@ -643,7 +642,7 @@ class ReductionStatusReporter(StatusReporter):
         """
         tracebacks = None if tb_path is None else cls._tracebacks(tb_path)
         return cls(
-            list(ReductionStatus.loadall(db_file=db_file, time_limit=time_limit)),
+            list(ReductionStatus.load_all(db_file, time_limit=time_limit)),
             tracebacks=tracebacks,
         )
 
@@ -652,7 +651,7 @@ class ReductionStatusReporter(StatusReporter):
         return (
             "Analysis",
             ", ".join(
-                ("%s: %d%%" % (desc, 100 * reliability))
+                f"{desc}: {100 * reliability:0.2f}%"
                 for desc, reliability in report.analysis.items()
             ),
         )
@@ -661,7 +660,7 @@ class ReductionStatusReporter(StatusReporter):
     def _crash_id_entry(report):
         crash_str = str(report.crash_id)
         if report.tool:
-            crash_str += " (%s)" % (report.tool,)
+            crash_str += f" ({report.tool})"
         return ("Crash ID", crash_str)
 
     @staticmethod
@@ -673,7 +672,7 @@ class ReductionStatusReporter(StatusReporter):
         return (
             "Run Parameters",
             ", ".join(
-                ("%s: %r" % (desc, value)) for desc, value in report.run_params.items()
+                (f"{desc}: {value!r}") for desc, value in report.run_params.items()
             ),
         )
 
@@ -682,16 +681,15 @@ class ReductionStatusReporter(StatusReporter):
         return (
             "Signature",
             ", ".join(
-                ("%s: %r" % (desc, value))
-                for desc, value in report.signature_info.items()
+                (f"{desc}: {value!r}") for desc, value in report.signature_info.items()
             ),
         )
 
-    def specific(  # pylint: disable=arguments-differ
+    def specific(
         self,
         sysinfo=False,
         timestamp=False,
-    ):
+    ):  # pylint: disable=arguments-renamed
         """Generate formatted output from status report.
 
         Args:
@@ -718,12 +716,9 @@ class ReductionStatusReporter(StatusReporter):
                 entries.append(
                     (
                         "Current Strategy",
-                        "%s (%r of %d)"
-                        % (
-                            report.current_strategy.name,
-                            report.current_strategy_idx,
-                            len(report.strategies),
-                        ),
+                        f"{report.current_strategy.name} "
+                        f"({report.current_strategy_idx!r} of "
+                        f"{len(report.strategies)})",
                     )
                 )
             if report.current_strategy and report.original:
@@ -731,8 +726,7 @@ class ReductionStatusReporter(StatusReporter):
                 entries.append(
                     (
                         "Current/Original",
-                        "%dB / %dB"
-                        % (report.current_strategy.size, report.original.size),
+                        f"{report.current_strategy.size}B / {report.original.size}B",
                     )
                 )
             if report.total:
@@ -740,19 +734,18 @@ class ReductionStatusReporter(StatusReporter):
                 entries.append(
                     (
                         "Results",
-                        "%d successes, %d attempts"
-                        % (report.total.successes, report.total.attempts),
+                        (
+                            f"{report.total.successes} successes,"
+                            f" {report.total.attempts} attempts"
+                        ),
                     )
                 )
             if report.total and report.current_strategy:
                 entries.append(
                     (
                         "Time Elapsed",
-                        "%s in strategy, %s total"
-                        % (
-                            _format_seconds(report.current_strategy.duration),
-                            _format_seconds(report.total.duration),
-                        ),
+                        f"{_format_seconds(report.current_strategy.duration)} in "
+                        f"strategy, {_format_seconds(report.total.duration)} total",
                     )
                 )
 
@@ -861,8 +854,8 @@ def main(args=None):
     basicConfig(format=log_fmt, datefmt="%Y-%m-%d %H:%M:%S", level=log_level)
 
     modes = {
-        "fuzzing": (StatusReporter, Status.STATUS_DB),
-        "reducing": (ReductionStatusReporter, ReductionStatus.STATUS_DB),
+        "fuzzing": (StatusReporter, STATUS_DB_FUZZ),
+        "reducing": (ReductionStatusReporter, STATUS_DB_REDUCE),
     }
 
     # report types: define name and time range of scan
@@ -875,7 +868,9 @@ def main(args=None):
 
     parser = ArgumentParser(description="Grizzly status report generator")
     parser.add_argument(
-        "--dump", help="File to write report to, existing files will be overwritten."
+        "--dump",
+        type=Path,
+        help="File to write report to, existing files will be overwritten.",
     )
     parser.add_argument(
         "--type",
@@ -883,13 +878,13 @@ def main(args=None):
         default="active",
         help="Report type. active: Current snapshot of activity, complete: "
         "Aggregate summary of all jobs over a longer duration (8h). "
-        "(default: active)",
+        "(default: %(default)s)",
     )
     parser.add_argument(
         "--scan-mode",
         choices=modes.keys(),
         default="fuzzing",
-        help="Report mode. (default: fuzzing)",
+        help="Report mode. (default: %(default)s)",
     )
     parser.add_argument(
         "--system-report",
@@ -898,21 +893,22 @@ def main(args=None):
     )
     parser.add_argument(
         "--tracebacks",
+        type=Path,
         help="Scan path for Python tracebacks found in screenlog.# files",
     )
     args = parser.parse_args(args)
-    if args.tracebacks and not isdir(args.tracebacks):
+    if args.tracebacks and not args.tracebacks.is_dir():
         parser.error("--tracebacks must be a directory")
 
     reporter_cls, status_db = modes.get(args.scan_mode)
     reporter = reporter_cls.load(
-        db_file=status_db,
+        status_db,
         tb_path=args.tracebacks,
         time_limit=report_types[args.type],
     )
 
     if args.dump:
-        with open(args.dump, "w") as ofp:
+        with args.dump.open("w") as ofp:
             if args.type == "active" and args.scan_mode == "fuzzing":
                 ofp.write(reporter.summary(runtime=False, sysinfo=True, timestamp=True))
             elif args.type == "active":
@@ -929,8 +925,8 @@ def main(args=None):
         return 0
 
     print(
-        "Grizzly Status - %s - Instance report frequency: %ds\n"
-        % (strftime("%Y/%m/%d %X"), Status.REPORT_FREQ)
+        f"Grizzly Status - {strftime('%Y/%m/%d %X')} - "
+        f"Instance report frequency: {REPORT_RATE}s\n"
     )
     print("[Reports]")
     print(reporter.specific())
