@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -63,7 +62,7 @@ class TestCase:
         self.adapter_name = adapter_name
         self.assets = None
         self.duration = None
-        self.env_vars = dict()
+        self.env_vars = {}
         self.hang = False
         self.input_fname = input_fname  # file that was used to create the test case
         self.landing_page = self.sanitize_path(landing_page)
@@ -73,7 +72,7 @@ class TestCase:
             self.redirect_page = None
         self.time_limit = time_limit
         self.timestamp = time() if timestamp is None else timestamp
-        self._files = TestFileMap(optional=list(), required=list())
+        self._files = TestFileMap(optional=[], required=[])
         self._data_path = Path(mkdtemp(prefix="testcase_", dir=grz_tmp("storage")))
 
     def __enter__(self):
@@ -156,7 +155,7 @@ class TestCase:
 
         test_file = TestFile(file_name, self._data_path / file_name)
         if test_file.file_name in self.contents:
-            raise TestFileExists("%r exists in test" % (test_file.file_name,))
+            raise TestFileExists(f"{test_file.file_name!r} exists in test")
 
         test_file.data_file.parent.mkdir(parents=True, exist_ok=True)
         if copy:
@@ -234,9 +233,9 @@ class TestCase:
             None
 
         Returns:
-            str: Path to directory containing test case files.
+            Path: Directory containing test case files.
         """
-        return str(self._data_path)
+        return self._data_path
 
     @property
     def data_size(self):
@@ -311,7 +310,7 @@ class TestCase:
         """Load TestCases from disk.
 
         Args:
-            path (str): Path can be:
+            path (Path): Path can be:
                         1) A directory containing `test_info.json` and data.
                         2) A directory with one or more subdirectories of 1.
                         3) A zip archive containing testcase data or
@@ -324,11 +323,11 @@ class TestCase:
         Returns:
             list: TestCases successfully loaded from path.
         """
-        path = Path(path)
+        assert isinstance(path, Path)
         # unpack archive if needed
         if path.name.lower().endswith(".zip"):
+            unpacked = mkdtemp(prefix="unpack_", dir=grz_tmp("storage"))
             try:
-                unpacked = mkdtemp(prefix="unpack_", dir=grz_tmp("storage"))
                 with ZipFile(path) as zip_fp:
                     zip_fp.extractall(path=unpacked)
             except (BadZipfile, zlib_error):
@@ -342,7 +341,7 @@ class TestCase:
             if path.is_file():
                 tests = [cls.load_single(path, adjacent=adjacent)]
             elif path.is_dir():
-                tests = list()
+                tests = []
                 assets = None
                 for tc_path in TestCase.scan_path(path):
                     tests.append(
@@ -382,13 +381,13 @@ class TestCase:
         Returns:
             TestCase: A TestCase.
         """
-        path = Path(path)
+        assert isinstance(path, Path)
         if path.is_dir():
             # load using test_info.json
             try:
                 with (path / "test_info.json").open("r") as in_fp:
                     info = json.load(in_fp)
-            except IOError:
+            except OSError:
                 raise TestCaseLoadFailure("Missing 'test_info.json'") from None
             except ValueError:
                 raise TestCaseLoadFailure("Invalid 'test_info.json'") from None
@@ -397,15 +396,15 @@ class TestCase:
             entry_point = Path(path / info["target"])
             if not entry_point.is_file():
                 raise TestCaseLoadFailure(
-                    "Entry point %r not found in %r" % (info["target"], str(path))
+                    f"Entry point {info['target']!r} not found in {path}"
                 )
             # always load all contents of a directory if a 'test_info.json' is loaded
             adjacent = True
         elif path.is_file():
             entry_point = path
-            info = dict()
+            info = {}
         else:
-            raise TestCaseLoadFailure("Missing or invalid TestCase %r" % (str(path),))
+            raise TestCaseLoadFailure(f"Missing or invalid TestCase '{path}'")
         # create testcase and add data
         test = cls(
             entry_point.relative_to(entry_point.parent).as_posix(),
@@ -432,7 +431,7 @@ class TestCase:
                 test.cleanup()
                 raise TestCaseLoadFailure(str(exc)) from None
             # load environment variables
-            test.env_vars = info.get("env", dict())
+            test.env_vars = info.get("env", {})
             assert isinstance(test.env_vars, dict)
             # sanity check environment variable data
             for name, value in test.env_vars.items():
@@ -503,7 +502,7 @@ class TestCase:
         Returns:
             None
         """
-        to_remove = list()
+        to_remove = []
         # iterate over optional files
         for idx, opt in enumerate(self._files.optional):
             # check entries in 'keep' for a match
@@ -526,12 +525,12 @@ class TestCase:
         assert isinstance(path, str)
         # check for missing filename or path containing drive letter (Windows)
         if split(path)[-1] in ("", ".", "..") or ":" in path:
-            raise ValueError("invalid path %r" % (path,))
+            raise ValueError(f"invalid path {path!r}")
         # normalize path
         path = normpath(path).replace("\\", "/")
         # check normalized path does not resolve to location outside of '.'
         if path.startswith("../"):
-            raise ValueError("invalid path %r" % (path,))
+            raise ValueError(f"invalid path {path!r}")
         return path.lstrip("/")
 
     @staticmethod
