@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -10,11 +9,11 @@ from sapphire import Sapphire
 from .adapter import Adapter
 from .common.plugins import load as load_plugin
 from .common.reporter import (
+    FailedLaunchReporter,
     FilesystemReporter,
     FuzzManagerReporter,
-    S3FuzzManagerReporter,
 )
-from .common.utils import TIMEOUT_DELAY, Exit, configure_logging
+from .common.utils import Exit, configure_logging, time_limits
 from .session import Session
 from .target import Target, TargetLaunchError, TargetLaunchTimeout
 
@@ -30,8 +29,6 @@ def main(args):
     LOG.info("Starting Grizzly (%d)", getpid())
     if args.fuzzmanager:
         FuzzManagerReporter.sanity_check(args.binary)
-    elif args.s3_fuzzmanager:
-        S3FuzzManagerReporter.sanity_check(args.binary)
 
     if args.headless:
         LOG.info("Running browser headless (%s)", args.headless)
@@ -45,31 +42,22 @@ def main(args):
         LOG.info("Running with Valgrind. This will be SLOW!")
 
     adapter = None
-    session = None
+    complete_with_results = False
     target = None
     try:
         LOG.debug("initializing Adapter %r", args.adapter)
         adapter = load_plugin(args.adapter, "grizzly_adapters", Adapter)(args.adapter)
 
-        # test case time limit and timeout sanity checking
-        if args.time_limit:
-            time_limit = args.time_limit
+        # calculate time limit and timeout
+        time_limit, timeout = time_limits(
+            args.time_limit, args.timeout, default_limit=adapter.TIME_LIMIT
+        )
+        if args.no_harness:
+            LOG.info("Using timeout: %ds (no harness)", timeout)
         else:
-            assert adapter.TIME_LIMIT >= 1
-            time_limit = adapter.TIME_LIMIT
-        if args.timeout:
-            timeout = args.timeout
-        else:
-            timeout = time_limit + TIMEOUT_DELAY
-        LOG.info("Using test time limit: %ds, timeout: %ds", time_limit, timeout)
-        if timeout < time_limit:
-            LOG.error("Timeout must be at least test time limit if not greater")
-            return Exit.ARGS
-        if adapter.HARNESS_FILE and time_limit == timeout:
-            LOG.warning(
-                "To avoid relaunches due to tests failing to close"
-                " themselves use a timeout greater than time limit"
-            )
+            LOG.info("Using time limit: %ds, timeout: %ds", time_limit, timeout)
+            if time_limit == timeout:
+                LOG.warning("To avoid unnecessary relaunches set timeout > time limit")
 
         if adapter.RELAUNCH > 0:
             LOG.info("Relaunch (%d) set in Adapter", adapter.RELAUNCH)
@@ -97,20 +85,13 @@ def main(args):
         if args.fuzzmanager:
             LOG.info("Results will be reported via FuzzManager")
             reporter = FuzzManagerReporter(tool=args.tool)
-        elif args.s3_fuzzmanager:
-            LOG.info(
-                "Results will be reported via FuzzManager w/ large attachments in S3"
-            )
-            reporter = S3FuzzManagerReporter(tool=args.tool)
         else:
             reporter = FilesystemReporter(args.logs / "results")
-            LOG.info("Results will be stored in %r", str(reporter.report_path))
+            LOG.info("Results will be stored in '%s'", reporter.report_path)
         reporter.display_logs = args.smoke_test or reporter.display_logs
 
-        # make sure an iteration limit is set if smoke_test is True
-        iteration_limit = (args.limit or 10) if args.smoke_test else args.limit
-        if iteration_limit:
-            LOG.info("%r iteration(s) will be attempted", iteration_limit)
+        if args.limit:
+            LOG.info("%r iteration(s) will be attempted", args.limit)
         if args.runtime:
             LOG.info("Runtime is limited to %rs", args.runtime)
 
@@ -121,7 +102,7 @@ def main(args):
         with Sapphire(auto_close=1, timeout=timeout) as server:
             target.reverse(server.port, server.port)
             LOG.debug("initializing the Session")
-            session = Session(
+            with Session(
                 adapter,
                 reporter,
                 server,
@@ -131,35 +112,35 @@ def main(args):
                 relaunch=relaunch,
                 report_limit=args.limit_reports,
                 report_size=args.collect,
-            )
-            if args.log_level == DEBUG or args.verbose:
-                display_mode = Session.DISPLAY_VERBOSE
-            else:
-                display_mode = Session.DISPLAY_NORMAL
-            session.run(
-                args.ignore,
-                time_limit,
-                input_path=str(args.input),
-                iteration_limit=iteration_limit,
-                result_limit=1 if args.smoke_test else 0,
-                runtime_limit=args.runtime,
-                display_mode=display_mode,
-                launch_attempts=args.launch_attempts,
-            )
+            ) as session:
+                if args.log_level == DEBUG or args.verbose:
+                    display_mode = Session.DISPLAY_VERBOSE
+                else:
+                    display_mode = Session.DISPLAY_NORMAL
+                session.run(
+                    args.ignore,
+                    time_limit,
+                    input_path=str(args.input),
+                    iteration_limit=args.limit,
+                    no_harness=args.no_harness,
+                    result_limit=1 if args.smoke_test else 0,
+                    runtime_limit=args.runtime,
+                    display_mode=display_mode,
+                    launch_attempts=args.launch_attempts,
+                )
+                complete_with_results = session.status.results.total > 0
 
     except KeyboardInterrupt:
         LOG.info("Ctrl+C detected.")
         return Exit.ABORT
 
     except (TargetLaunchError, TargetLaunchTimeout) as exc:
-        LOG.error(str(exc))
+        if isinstance(exc, TargetLaunchError) and exc.report:
+            FailedLaunchReporter(args.display_launch_failures).submit([], exc.report)
         return Exit.LAUNCH_FAILURE
 
     finally:
         LOG.info("Shutting down...")
-        if session is not None:
-            LOG.debug("calling session.close()")
-            session.close()
         if target is not None:
             LOG.debug("calling target.cleanup()")
             target.cleanup()
@@ -168,6 +149,6 @@ def main(args):
             adapter.cleanup()
         LOG.info("Done.")
 
-    if session and session.status.results.total > 0:
+    if complete_with_results:
         return Exit.ERROR
     return Exit.SUCCESS
