@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -29,6 +28,6 @@ def reporter_sequential_strftime(mocker):
     prefix = mocker.patch("grizzly.common.report.strftime")
 
     def report_prefix(_):
-        return "%04d" % (prefix.call_count,)
+        return f"{prefix.call_count:0>4d}"
 
     prefix.side_effect = report_prefix
