@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -18,11 +17,16 @@ from sapphire import Sapphire
 
 from ..common.fuzzmanager import CrashEntry
 from ..common.plugins import load as load_plugin
-from ..common.reporter import FilesystemReporter, FuzzManagerReporter, Quality
-from ..common.status import ReductionStatus
+from ..common.reporter import (
+    FailedLaunchReporter,
+    FilesystemReporter,
+    FuzzManagerReporter,
+    Quality,
+)
+from ..common.status import STATUS_DB_REDUCE, ReductionStatus
 from ..common.status_reporter import ReductionStatusReporter
 from ..common.storage import TestCaseLoadFailure
-from ..common.utils import ConfigError, Exit, configure_logging, grz_tmp
+from ..common.utils import ConfigError, Exit, configure_logging, time_limits
 from ..replay import ReplayManager
 from ..target import Target, TargetLaunchError, TargetLaunchTimeout
 from .exceptions import GrizzlyReduceBaseException, NotReproducible
@@ -138,6 +142,7 @@ class ReduceManager:
         self._signature_desc = signature_desc
         self._static_timeout = expect_hang or static_timeout
         self._status = ReductionStatus.start(
+            STATUS_DB_REDUCE,
             strategies=strategies,
             testcase_size_cb=self.testcase_size,
             crash_id=reducer_crash_id,
@@ -781,14 +786,14 @@ class ReduceManager:
         try:
             if args.sig:
                 signature = CrashSignature.fromFile(args.sig)
-                meta = Path(args.sig).with_suffix(".metadata")
+                meta = args.sig.with_suffix(".metadata")
                 if meta.is_file():
                     meta = json.loads(meta.read_text())
                     signature_desc = meta["shortDescription"]
 
             try:
                 testcases, assets, env_vars = ReplayManager.load_testcases(
-                    str(args.input), subset=args.test_index
+                    args.input, subset=args.test_index
                 )
             except TestCaseLoadFailure as exc:
                 LOG.error("Error: %s", str(exc))
@@ -799,7 +804,7 @@ class ReduceManager:
                     "Setting default --tool=grizzly-%s from testcase",
                     testcases[0].adapter_name,
                 )
-                args.tool = "grizzly-%s" % (testcases[0].adapter_name,)
+                args.tool = f"grizzly-{testcases[0].adapter_name}"
 
             expect_hang = ReplayManager.expect_hang(args.ignore, signature, testcases)
 
@@ -810,14 +815,10 @@ class ReduceManager:
                         "testcases. Perhaps '--test-index' can help."
                     )
                     return Exit.ARGS
-                LOG.debug("--no-harness specified relaunch set to 1")
-                args.relaunch = 1
 
             # check test time limit and timeout
             # TODO: add support for test time limit, use timeout in both cases for now
-            _, timeout = ReplayManager.time_limits(
-                args.timeout, args.timeout, testcases
-            )
+            _, timeout = time_limits(args.timeout, args.timeout, tests=testcases)
 
             args.repeat = max(args.min_crashes, args.repeat)
             relaunch = min(args.relaunch, args.repeat)
@@ -884,12 +885,10 @@ class ReduceManager:
             return Exit.ABORT
 
         except (TargetLaunchError, TargetLaunchTimeout) as exc:
-            LOG.error("Exception: %s", exc)
             if isinstance(exc, TargetLaunchError) and exc.report:
-                path = grz_tmp("launch_failures")
-                LOG.error("Logs can be found here %r", path)
-                reporter = FilesystemReporter(path, major_bucket=False)
-                reporter.submit([], exc.report)
+                FailedLaunchReporter(args.display_launch_failures).submit(
+                    [], exc.report
+                )
             return Exit.LAUNCH_FAILURE
 
         except GrizzlyReduceBaseException as exc:
