@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -22,8 +21,7 @@ LOG = getLogger(__name__)
 pytestmark = mark.usefixtures(
     "reporter_sequential_strftime",
     "tmp_path_fm_config",
-    "tmp_path_replay_status_db",
-    "tmp_path_reduce_status_db",
+    "tmp_path_status_db_reduce",
 )
 
 
@@ -33,7 +31,7 @@ def test_strategy_tc_load(is_hang):
 
     class _TestStrategy(Strategy):
         def __iter__(self):
-            yield TestCase.load(str(self._testcase_root), False)
+            yield TestCase.load(self._testcase_root, False)
 
         def update(self, success, served=None):
             pass
@@ -162,10 +160,10 @@ def test_list(
             if contents == "required" and required_first:
                 required_seen = True
             elif contents == "123" and (required_seen or not required_first):
-                log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+                log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
                 log_path.mkdir()
                 _fake_save_logs_foo(log_path)
-                report = Report(str(log_path), "bin")
+                report = Report(log_path, "bin")
                 return [
                     ReplayResult(report, [["test.html"]] * len(testcases), [], True)
                 ]
@@ -181,7 +179,7 @@ def test_list(
     log_path = tmp_path / "logs"
 
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     try:
         mgr = ReduceManager(
@@ -345,10 +343,10 @@ def test_purge_unserved(
                         return []
         if not has_any:
             return []
-        log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+        log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
         log_path.mkdir()
         _fake_save_logs_foo(log_path)
-        report = Report(str(log_path), "bin")
+        report = Report(log_path, "bin")
         return [ReplayResult(report, served.pop(0), [], True)]
 
     replayer.run.side_effect = replay_run
@@ -362,7 +360,7 @@ def test_purge_unserved(
     log_path = tmp_path / "logs"
 
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     try:
         mgr = ReduceManager(
@@ -406,10 +404,10 @@ def test_dd_only(mocker, tmp_path):
             LOG.debug("interesting if 'required' in %r", contents)
             interesting = "required" in contents
             if interesting:
-                log_path = tmp_path / ("crash%d_logs" % (replayer.run.call_count,))
+                log_path = tmp_path / f"crash{replayer.run.call_count}_logs"
                 log_path.mkdir()
                 _fake_save_logs_foo(log_path)
-                report = Report(str(log_path), "bin")
+                report = Report(log_path, "bin")
                 return [ReplayResult(report, [["test.html", "other.html"]], [], True)]
         return []
 
@@ -422,7 +420,7 @@ def test_dd_only(mocker, tmp_path):
     log_path = tmp_path / "logs"
 
     target = mocker.Mock(spec_set=Target)
-    target.filtered_environ.return_value = dict()
+    target.filtered_environ.return_value = {}
     target.assets = mocker.Mock(spec_set=AssetManager)
     try:
         mgr = ReduceManager(
