@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -12,11 +11,16 @@ from FTB.Signatures.CrashInfo import CrashSignature
 from sapphire import Sapphire, ServerMap
 
 from ..common.plugins import load as load_plugin
-from ..common.reporter import FilesystemReporter, FuzzManagerReporter, Report
+from ..common.reporter import (
+    FailedLaunchReporter,
+    FilesystemReporter,
+    FuzzManagerReporter,
+    Report,
+)
 from ..common.runner import Runner
-from ..common.status import Status
+from ..common.status import SimpleStatus
 from ..common.storage import TestCase, TestCaseLoadFailure
-from ..common.utils import TIMEOUT_DELAY, ConfigError, Exit, configure_logging, grz_tmp
+from ..common.utils import ConfigError, Exit, configure_logging, grz_tmp, time_limits
 from ..target import Result, Target, TargetLaunchError, TargetLaunchTimeout
 
 __author__ = "Tyson Smith"
@@ -38,8 +42,6 @@ class ReplayResult:
 
 class ReplayManager:
     HARNESS_FILE = str(Path(__file__).parent / ".." / "common" / "harness.html")
-    DEFAULT_TIME_LIMIT = 30
-    STATUS_DB = str(Path(grz_tmp()) / "replay-status.db")
 
     __slots__ = (
         "ignore",
@@ -138,7 +140,7 @@ class ReplayManager:
         """Load TestCases.
 
         Args:
-            path (str): Path to load.
+            path (Path): Path to load.
             subset (list(int)): Indices of tests to load when loading multiple
                                 tests.
         Returns:
@@ -170,7 +172,7 @@ class ReplayManager:
             # deduplicate and limit requested indices to valid range
             reqs = {max(count + x, 0) if x < 0 else min(x, count - 1) for x in subset}
             LOG.debug("using TestCase(s) with index %r", reqs)
-            selected = list()
+            selected = []
             for idx in sorted(reqs, reverse=True):
                 selected.append(testcases.pop(idx))
             selected.reverse()
@@ -209,6 +211,27 @@ class ReplayManager:
             for result in expected:
                 reporter.submit(tests or [], report=result.report)
 
+    @staticmethod
+    def report_to_fuzzmanager(results, tests, tool=None):
+        """Use FuzzManagerReporter to send reports to a FuzzManager server.
+
+        Args:
+            results (iterable): ReplayResult to output.
+            tests (iterable): Testcases to output.
+            tool (str): Name used by FuzzManager.
+
+        Returns:
+            None
+        """
+        if tests and not tool:
+            tool = tests[0].adapter_name
+        reporter = FuzzManagerReporter(tool or "grizzly-replay")
+        for result in results:
+            # always report expected results
+            # avoid reporting unexpected frequent results
+            reporter.force_report = result.expected
+            reporter.submit(tests, result.report)
+
     def run(
         self,
         testcases,
@@ -254,11 +277,12 @@ class ReplayManager:
         assert repeat > 0
         assert repeat >= min_results
         assert testcases
-        assert time_limit > 0
+        assert time_limit > 0 or self._harness is None
+        assert self._harness or self._harness is None
         assert self._harness is not None or len(testcases) == 1
         assert not expect_hang or self._signature is not None
 
-        self.status = Status.start(db_file=self.STATUS_DB)
+        self.status = SimpleStatus.start()
 
         server_map = ServerMap()
         if self._harness is None:
@@ -270,7 +294,7 @@ class ReplayManager:
             server_map.set_redirect("grz_start", "grz_harness", required=False)
 
         # track unprocessed results
-        reports = dict()
+        reports = {}
         try:
             sig_hash = Report.calc_hash(self._signature) if self._signature else None
             test_count = len(testcases)
@@ -288,25 +312,19 @@ class ReplayManager:
                 if on_iteration_cb is not None:
                     on_iteration_cb()
                 if self.target.closed:
-                    if self._harness is None:
-                        location = runner.location(
-                            "/grz_start",
-                            self.server.port,
-                            post_launch_delay=post_launch_delay,
-                        )
-                    else:
-                        location = runner.location(
-                            "/grz_start",
-                            self.server.port,
-                            close_after=relaunch * test_count,
-                            post_launch_delay=post_launch_delay,
-                            time_limit=time_limit,
-                        )
+                    location = runner.location(
+                        "/grz_start",
+                        self.server.port,
+                        close_after=relaunch * test_count if self._harness else None,
+                        post_launch_delay=post_launch_delay,
+                        time_limit=time_limit if self._harness else None,
+                    )
                     runner.launch(location, max_retries=launch_attempts)
                     runner.post_launch(delay=post_launch_delay)
                 # run tests
-                durations = list()
-                served = list()
+                durations = []
+                served = []
+                run_result = None
                 for test_idx in range(test_count):
                     if test_count > 1:
                         LOG.info(
@@ -344,6 +362,7 @@ class ReplayManager:
                     served.append(run_result.served)
                     if run_result.status != Result.NONE or not run_result.attempted:
                         break
+                assert run_result is not None
                 if not run_result.attempted:
                     LOG.warning("Test case was not served")
                     if runner.initial:
@@ -361,7 +380,7 @@ class ReplayManager:
                     log_path = mkdtemp(prefix="logs_", dir=grz_tmp("logs"))
                     self.target.save_logs(log_path)
                     report = Report(
-                        log_path, self.target.binary, is_hang=run_result.timeout
+                        Path(log_path), self.target.binary, is_hang=run_result.timeout
                     )
                     # check signatures
                     if run_result.timeout:
@@ -432,7 +451,14 @@ class ReplayManager:
                         report = None
                 elif run_result.status == Result.IGNORED:
                     self.status.ignored += 1
-                    LOG.info("Result: Ignored (%d)", self.status.ignored)
+                    if run_result.timeout:
+                        LOG.info(
+                            "Result: Ignored (%d); timeout, idle: %r",
+                            self.status.ignored,
+                            run_result.idle,
+                        )
+                    else:
+                        LOG.info("Result: Ignored (%d)", self.status.ignored)
 
                 if exit_early and self.status.iteration < repeat:
                     # check if failed to meet minimum number of results
@@ -475,7 +501,7 @@ class ReplayManager:
                     results = list(reports.values())
                 else:
                     # add only unexpected results since min_results was not reached
-                    results = list()
+                    results = []
                     for report in reports.values():
                         if report.expected:
                             report.report.cleanup()
@@ -490,7 +516,7 @@ class ReplayManager:
                 # there should be at most one expected bucket
                 assert sum(x.expected for x in reports.values()) <= 1
                 # filter out unreliable expected results
-                results = list()
+                results = []
                 for crash_hash, report in reports.items():
                     if report.expected and report.count < min_results:
                         LOG.debug(
@@ -523,41 +549,11 @@ class ReplayManager:
             for report in reports.values():
                 report.report.cleanup()
 
-    @classmethod
-    def time_limits(cls, time_limit, timeout, tests):
-        """Determine the test time limit and timeout. A ConfigError is raised
-        if configuration errors are detected.
-
-        Args:
-            time_limit (int): Test time limit.
-            timeout (int): Iteration timeout.
-            tests (iterable): Testcases that may contain time limit values.
-
-        Returns:
-            tuple (int, int): Time limit and timeout.
-        """
-        if time_limit is None:
-            test_limits = tuple(int(x.time_limit) for x in tests if x.time_limit)
-            if test_limits:
-                time_limit = max(test_limits)
-            else:
-                time_limit = cls.DEFAULT_TIME_LIMIT
-        if timeout is None:
-            timeout = time_limit + TIMEOUT_DELAY
-        if timeout < time_limit:
-            raise ConfigError(
-                "Timeout (%d) cannot be less than time limit (%d)"
-                % (timeout, time_limit),
-                Exit.ARGS,
-            )
-        return time_limit, timeout
-
     @classmethod
     def main(cls, args):
         configure_logging(args.log_level)
         if args.fuzzmanager:
             FuzzManagerReporter.sanity_check(args.binary)
-            # TODO: add fuzzmanager support
 
         LOG.info("Starting Grizzly Replay")
 
@@ -572,14 +568,11 @@ class ReplayManager:
         elif args.valgrind:
             LOG.info("Running with Valgrind. This will be SLOW!")
 
-        if args.sig:
-            signature = CrashSignature.fromFile(args.sig)
-        else:
-            signature = None
+        signature = CrashSignature.fromFile(args.sig) if args.sig else None
 
         try:
             testcases, assets, env_vars = cls.load_testcases(
-                str(args.input), subset=args.test_index
+                args.input, subset=args.test_index
             )
         except TestCaseLoadFailure as exc:
             LOG.error("Error: %s", str(exc))
@@ -596,17 +589,17 @@ class ReplayManager:
                 return Exit.ARGS
             # check if hangs are expected
             expect_hang = cls.expect_hang(args.ignore, signature, testcases)
-            # check test time limit and timeout
-            time_limit, timeout = cls.time_limits(
-                args.time_limit, args.timeout, testcases
+            # calculate test time limit and timeout
+            time_limit, timeout = time_limits(
+                args.time_limit, args.timeout, tests=testcases
             )
-            LOG.info("Using time limit: %ds, timeout: %ds", time_limit, timeout)
-            repeat = max(args.min_crashes, args.repeat)
             if args.no_harness:
-                LOG.debug("no-harness enabled, forcing relaunch=1")
-                relaunch = 1
+                LOG.info("Using timeout: %ds (no harness)", timeout)
             else:
-                relaunch = min(args.relaunch, repeat)
+                LOG.info("Using time limit: %ds, timeout: %ds", time_limit, timeout)
+            # calculate repeat and relaunch
+            repeat = max(args.min_crashes, args.repeat)
+            relaunch = min(args.relaunch, repeat)
             LOG.info(
                 "Repeat: %d, Minimum crashes: %d, Relaunch %d",
                 repeat,
@@ -625,11 +618,10 @@ class ReplayManager:
                 rr=args.rr,
                 valgrind=args.valgrind,
             )
-            # local environ takes priority over environ loaded from test case
             if env_vars is not None:
-                env_vars.update(target.environ)
-                target.environ = env_vars
-                env_vars = None
+                LOG.debug("adding environment loaded from test case")
+                target.merge_environment(env_vars)
+
             # TODO: support overriding existing assets
             # prioritize specified assets over included
             target.assets.add_batch(args.asset)
@@ -662,10 +654,12 @@ class ReplayManager:
             # handle results
             success = any(x.expected for x in results)
             if success:
-                LOG.info("Result successfully reproduced")
+                LOG.info("Results successfully reproduced")
+            elif any(results):
+                LOG.info("Results detected, signature does not match")
             else:
-                LOG.info("Failed to reproduce results")
-            if args.logs and results:
+                LOG.info("No results detected")
+            if results and (args.logs or args.fuzzmanager):
                 # add target assets to test cases
                 if not target.assets.is_empty():
                     for test in testcases:
@@ -674,10 +668,13 @@ class ReplayManager:
                 if target.filtered_environ():
                     for test in testcases:
                         test.env_vars = target.filtered_environ()
-                cls.report_to_filesystem(
-                    args.logs, results, testcases if args.include_test else None
-                )
-            # TODO: add fuzzmanager reporting
+                # report results
+                if args.fuzzmanager:
+                    cls.report_to_fuzzmanager(results, testcases, tool=args.tool)
+                else:
+                    cls.report_to_filesystem(
+                        args.logs, results, testcases if args.include_test else None
+                    )
             return Exit.SUCCESS if success else Exit.FAILURE
 
         except ConfigError as exc:
@@ -688,12 +685,10 @@ class ReplayManager:
             return Exit.ABORT
 
         except (TargetLaunchError, TargetLaunchTimeout) as exc:
-            LOG.error(str(exc))
             if isinstance(exc, TargetLaunchError) and exc.report:
-                path = grz_tmp("launch_failures")
-                LOG.error("Logs can be found here %r", path)
-                reporter = FilesystemReporter(path, major_bucket=False)
-                reporter.submit([], exc.report)
+                FailedLaunchReporter(args.display_launch_failures).submit(
+                    [], exc.report
+                )
             return Exit.LAUNCH_FAILURE
 
         finally:
