@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -18,9 +17,7 @@ from ..common.storage import TestCase, TestCaseLoadFailure
 from ..target import AssetManager, Result, Target
 from .replay import ReplayManager, ReplayResult
 
-pytestmark = mark.usefixtures(
-    "patch_collector", "tmp_path_grz_tmp", "tmp_path_replay_status_db"
-)
+pytestmark = mark.usefixtures("patch_collector", "tmp_path_grz_tmp")
 
 
 def _fake_save_logs(result_logs, _meta=False):
@@ -218,22 +215,19 @@ def test_replay_06(mocker):
 
 
 def test_replay_07(mocker):
-    """test ReplayManager.run() - ignored"""
+    """test ReplayManager.run() - ignored (timeout)"""
     server = mocker.Mock(spec_set=Sapphire, port=0x1337)
-    server.serve_path.return_value = (Served.ALL, ["a.html"])
+    server.serve_path.return_value = (Served.TIMEOUT, ["a.html"])
     target = mocker.Mock(spec_set=Target, closed=True, launch_timeout=30)
     target.check_result.return_value = Result.IGNORED
-    target.monitor.is_healthy.return_value = False
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    target.handle_hang.return_value = True
+    testcases = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager([], server, target, use_harness=False) as replay:
         assert not replay.run(testcases, 10)
-        assert target.monitor.is_healthy.call_count == 1
-        assert target.close.call_count == 2
         assert replay.status.ignored == 1
         assert replay.status.iteration == 1
         assert replay.status.results.total == 0
+    assert target.handle_hang.call_count == 1
 
 
 def test_replay_08(mocker):
@@ -716,6 +710,7 @@ def test_replay_21(mocker, tmp_path):
     # success
     fake_load.return_value = [test0, test1]
     tests, assets, env_vars = ReplayManager.load_testcases(str(tmp_path))
+    assert env_vars
     assert env_vars["env"] == "var"
     assert not any(x.env_vars for x in tests)
     assert len(tests) == 2
@@ -807,3 +802,31 @@ def test_replay_22(mocker, expect_hang, is_hang, use_sig, match_sig, ignored, re
         assert len(found[0].durations) == 1
         assert testcase.hang == is_hang
         found[0].report.cleanup()
+
+
+def test_replay_23(mocker):
+    """test ReplayManager.report_to_fuzzmanager()"""
+    reporter = mocker.patch("grizzly.replay.replay.FuzzManagerReporter")
+    # no reports or tests
+    ReplayManager.report_to_fuzzmanager([], [])
+    assert reporter.call_args == (("grizzly-replay",),)
+    assert reporter.return_value.submit.call_count == 0
+    reporter.reset_mock()
+    # with reports and tests
+    results = [
+        mocker.Mock(
+            spec_set=ReplayResult, report=mocker.Mock(spec_set=Report), expected=True
+        ),
+        mocker.Mock(
+            spec_set=ReplayResult, report=mocker.Mock(spec_set=Report), expected=False
+        ),
+    ]
+    test = mocker.Mock(spec_set=TestCase, adapter_name="test-tool-name")
+    ReplayManager.report_to_fuzzmanager(results, [test])
+    assert reporter.call_args == (("test-tool-name",),)
+    assert reporter.return_value.submit.call_count == 2
+    reporter.reset_mock()
+    # with reports and no tests
+    ReplayManager.report_to_fuzzmanager(results, [], tool="test-override")
+    assert reporter.call_args == (("test-override",),)
+    assert reporter.return_value.submit.call_count == 2
