@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -34,6 +33,27 @@ __credits__ = ["Tyson Smith", "Jesse Schwartzentruber"]
 LOG = getLogger(__name__)
 
 
+class PuppetMonitor(TargetMonitor):
+    def __init__(self, puppet):
+        self._puppet = puppet
+
+    def clone_log(self, log_id, offset=0):
+        return self._puppet.clone_log(log_id, offset=offset)
+
+    def is_running(self):
+        return self._puppet.is_running()
+
+    def is_healthy(self):
+        return self._puppet.is_healthy()
+
+    @property
+    def launches(self):
+        return self._puppet.launches
+
+    def log_length(self, log_id):
+        return self._puppet.log_length(log_id)
+
+
 class PuppetTarget(Target):
     SUPPORTED_ASSETS = (
         # file containing line separated list of tokens to scan stderr/out for
@@ -57,6 +77,8 @@ class PuppetTarget(Target):
         "UBSAN_OPTIONS",
         "GNOME_ACCESSIBILITY",
         "MOZ_CHAOSMODE",
+        "MOZ_FUZZ_CRASH_ON_LARGE_ALLOC",
+        "MOZ_FUZZ_LARGE_ALLOC_LIMIT",
         "XPCOM_DEBUG_BREAK",
     )
 
@@ -110,7 +132,7 @@ class PuppetTarget(Target):
     def create_report(self, is_hang=False):
         logs = mkdtemp(prefix="logs_", dir=grz_tmp("logs"))
         self.save_logs(logs)
-        return Report(logs, self.binary, is_hang=is_hang)
+        return Report(Path(logs), self.binary, is_hang=is_hang)
 
     def filtered_environ(self):
         # remove context specific entries from environment
@@ -124,7 +146,7 @@ class PuppetTarget(Target):
             opts.pop("log_path")
             opts.pop("strip_path_prefix")
             opts.pop("suppressions")
-            filtered[san] = opts.options
+            filtered[san] = str(opts)
         # remove empty entries
         return {k: v for k, v in filtered.items() if v}
 
@@ -137,26 +159,7 @@ class PuppetTarget(Target):
     @property
     def monitor(self):
         if self._monitor is None:
-
-            class _PuppetMonitor(TargetMonitor):
-                # pylint: disable=no-self-argument,protected-access
-                def clone_log(_, log_id, offset=0):
-                    return self._puppet.clone_log(log_id, offset=offset)
-
-                def is_running(_):
-                    return self._puppet.is_running()
-
-                def is_healthy(_):
-                    return self._puppet.is_healthy()
-
-                @property
-                def launches(_):
-                    return self._puppet.launches
-
-                def log_length(_, log_id):
-                    return self._puppet.log_length(log_id)
-
-            self._monitor = _PuppetMonitor()
+            self._monitor = PuppetMonitor(self._puppet)
         return self._monitor
 
     def check_result(self, ignored):
@@ -214,6 +217,10 @@ class PuppetTarget(Target):
         return was_idle
 
     def dump_coverage(self, timeout=90):
+        if system() != "Linux":
+            LOG.debug("dump_coverage() only supported on Linux")
+            return
+
         assert SIGUSR1 is not None
         pid = self._puppet.get_pid()
         if pid is None or not self._puppet.is_healthy():
@@ -221,11 +228,11 @@ class PuppetTarget(Target):
             return
         # If at this point, the browser is in a good state, i.e. no crashes
         # or hangs, so signal the browser to dump coverage.
-        signaled_pids = list()
+        running_procs = 0
+        signaled_pids = []
         try:
             # send SIGUSR1 to browser processes
             parent_proc = Process(pid)
-            running_procs = 0
             for proc in chain([parent_proc], parent_proc.children(recursive=True)):
                 # avoid sending SIGUSR1 to non-browser processes
                 if Path(proc.exe()).name.startswith("firefox"):
@@ -317,7 +324,6 @@ class PuppetTarget(Target):
                 env_mod=env_mod,
             )
         except LaunchError as exc:
-            LOG.error("FFPuppet LaunchError: %s", str(exc))
             self.close()
             if isinstance(exc, BrowserTimeoutError):
                 raise TargetLaunchTimeout(str(exc)) from None
@@ -326,6 +332,26 @@ class PuppetTarget(Target):
     def log_size(self):
         return self._puppet.log_length("stderr") + self._puppet.log_length("stdout")
 
+    def merge_environment(self, extra):
+        output = dict(extra)
+        if self.environ:
+            # prioritize existing environment variables
+            output.update(self.environ)
+            # merge contents of *SAN_OPTIONS
+            org = SanitizerOptions()
+            out = SanitizerOptions()
+            for san in ("ASAN", "LSAN", "TSAN", "UBSAN"):
+                opts = "_".join((san, "OPTIONS"))
+                org.load_options(self.environ.get(opts, ""))
+                if not org:
+                    # nothing to add from original
+                    continue
+                out.load_options(extra.get(opts, ""))
+                for opt, value in org:  # pylint: disable=not-an-iterable
+                    out.add(opt, value, overwrite=True)
+                output[opts] = str(out)
+        self.environ = output
+
     def process_assets(self):
         self._extension = self.assets.get("extension")
         self._prefs = self.assets.get("prefs")
@@ -340,7 +366,7 @@ class PuppetTarget(Target):
         abort_tokens = self.assets.get("abort-tokens")
         if abort_tokens:
             LOG.debug("loading 'abort tokens' from %r", abort_tokens)
-            with open(abort_tokens, "r") as in_fp:
+            with open(abort_tokens) as in_fp:
                 for line in in_fp:
                     line = line.strip()
                     if line:
@@ -349,9 +375,9 @@ class PuppetTarget(Target):
         # configure sanitizer suppressions
         opts = SanitizerOptions()
         for sanitizer in ("lsan", "tsan", "ubsan"):
-            asset = "%s-suppressions" % (sanitizer,)
+            asset = f"{sanitizer}-suppressions"
             # load existing sanitizer options from environment
-            var_name = "%s_OPTIONS" % (sanitizer.upper(),)
+            var_name = f"{sanitizer.upper()}_OPTIONS"
             opts.load_options(self.environ.get(var_name, ""))
             if self.assets.get(asset):
                 # use suppression file if provided as asset
@@ -375,7 +401,7 @@ class PuppetTarget(Target):
                 continue
             # update sanitized *SAN_OPTIONS
             LOG.debug("updating suppressions in %r", var_name)
-            self.environ[var_name] = opts.options
+            self.environ[var_name] = str(opts)
 
     def save_logs(self, *args, **kwargs):
         self._puppet.save_logs(*args, **kwargs)
