@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -9,12 +8,25 @@ from pytest import mark, raises
 from .args import CommonArgs, GrizzlyArgs
 
 
-def test_common_args_01(mocker, tmp_path):
+@mark.parametrize(
+    "extra_args, results",
+    [
+        # test default
+        ([], {}),
+        # test no-harness and relaunch
+        (["--no-harness"], {"relaunch": 1}),
+    ],
+)
+def test_common_args_01(mocker, tmp_path, extra_args, results):
     """test CommonArgs.parse_args() - success"""
     mocker.patch("grizzly.args.scan_plugins", return_value=["targ"])
     fake_bin = tmp_path / "fake.bin"
     fake_bin.touch()
-    CommonArgs().parse_args(argv=[str(fake_bin), "--platform", "targ"])
+    cmd = [str(fake_bin), "--platform", "targ"] + extra_args
+    args = vars(CommonArgs().parse_args(argv=cmd))
+    assert args
+    for arg_name, expected_value in results.items():
+        assert args[arg_name] == expected_value, f"'{arg_name}' does not match"
 
 
 @mark.parametrize(
@@ -45,6 +57,12 @@ def test_common_args_02(capsys, mocker, args, msg, idx):
         (["--log-limit", "-1"], "error: --log-limit must be >= 0", ["targ1"]),
         # test invalid memory limit
         (["--memory", "-1"], "error: --memory must be >= 0", ["targ1"]),
+        # test --no-harness and --time-limit
+        (
+            ["--no-harness", "--time-limit", "10"],
+            "error: --time-limit cannot be used with --no-harness",
+            ["targ1"],
+        ),
         # test invalid relaunch value
         (["--relaunch", "0"], "error: --relaunch must be >= 1", ["targ1"]),
         # test invalid asset
@@ -71,10 +89,16 @@ def test_common_args_02(capsys, mocker, args, msg, idx):
             "error: --timeout must be >= 1",
             ["targ1"],
         ),
+        # test timeout < time-limit
+        (
+            ["--platform", "targ1", "--timeout", "1", "--time-limit", "10"],
+            "error: --timeout must be >= --time-limit",
+            ["targ1"],
+        ),
         # test invalid tool usage
         (
             ["--platform", "targ1", "--tool", "x"],
-            "error: --tool can only be given with --fuzzmanager",
+            "error: --tool requires --fuzzmanager",
             ["targ1"],
         ),
         # test invalid launch-attempts value
@@ -112,7 +136,28 @@ def test_common_args_04(tmp_path):
     CommonArgs().parse_args([str(fake_bin), "--logs", str(tmp_path)])
 
 
-def test_grizzly_args_01(mocker, tmp_path):
+def test_common_args_05(mocker):
+    """test CommonArgs.is_headless()"""
+    mocker.patch("grizzly.args.system", autospec=True, return_value="Linux")
+    getenv = mocker.patch("grizzly.args.getenv", autospec=True)
+    # test not headless
+    getenv.return_value = ":0"
+    assert not CommonArgs.is_headless()
+    # test headless
+    getenv.return_value = None
+    assert CommonArgs.is_headless()
+
+
+@mark.parametrize(
+    "extra_args, results",
+    [
+        # test default
+        ([], {}),
+        # test smoke-test
+        (["--smoke-test"], {"limit": 10}),
+    ],
+)
+def test_grizzly_args_01(mocker, tmp_path, extra_args, results):
     """test GrizzlyArgs.parse_args() - success"""
     mocker.patch(
         "grizzly.args.scan_plugins",
@@ -121,7 +166,11 @@ def test_grizzly_args_01(mocker, tmp_path):
     )
     fake_bin = tmp_path / "fake.bin"
     fake_bin.touch()
-    assert GrizzlyArgs().parse_args(argv=[str(fake_bin), "adpt", "--platform", "targ"])
+    cmd = [str(fake_bin), "adpt", "--platform", "targ"] + extra_args
+    args = vars(GrizzlyArgs().parse_args(argv=cmd))
+    assert args
+    for arg_name, expected_value in results.items():
+        assert args[arg_name] == expected_value, f"'{arg_name}' does not match"
 
 
 @mark.parametrize(
@@ -156,11 +205,6 @@ def test_grizzly_args_03(capsys, mocker):
     [
         # test invalid collect value
         (["--collect", "0"], "error: --collect must be greater than 0"),
-        # test enabling both fuzzmanager and s3-fuzzmanager reporters
-        (
-            ["--fuzzmanager", "--s3-fuzzmanager"],
-            "error: --fuzzmanager and --s3-fuzzmanager are mutually exclusive",
-        ),
         # test missing input
         (["--input", "missing"], "error: 'missing' does not exist"),
         # test invalid limit value
@@ -169,11 +213,6 @@ def test_grizzly_args_03(capsys, mocker):
         (["--limit-reports", "-1"], "error: --limit-reports must be >= 0"),
         # test runtime limit value
         (["--runtime", "-1"], "error: --runtime must be >= 0"),
-        # test tool
-        (
-            ["--tool", "x"],
-            "error: --tool can only be given with --fuzzmanager/--s3-fuzzmanager",
-        ),
     ],
 )
 def test_grizzly_args_04(capsys, mocker, tmp_path, args, msg):
